# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-Vars
Version:	0.013
Release:	1.%{__distinit}%{__distvers}
Summary:	Detects unused variables
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Test-Vars/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DR/DROLSKY/Test-Vars-%{version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# ===================================================================
# Build requirements
# ===================================================================
BuildRequires:	coreutils
BuildRequires:	perl >= 4:5.10.0
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(Module::Build::Tiny) >= 0.035
BuildRequires:	sed
# ===================================================================
# Module requirements
# ===================================================================
BuildRequires:	perl(B)
BuildRequires:	perl(constant)
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(IO::Pipe)
BuildRequires:	perl(parent)
BuildRequires:	perl(Storable)
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test::Builder::Module)
BuildRequires:	perl(warnings)
# ===================================================================
# Test suite requirements
# ===================================================================
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Tester)
# ===================================================================
# Optional test requirements
# ===================================================================
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Moose::Role)
BuildRequires:	perl(Test::Output)
%endif
# ===================================================================
# Author/Release test requirements
# ===================================================================
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Synopsis)
# ===================================================================
# Runtime requirements
# ===================================================================
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Test::Vars finds unused variables in order to keep the source code tidy.

%prep
%setup -q -n Test-Vars-%{version}

# Placate rpmlint about script interpreters in examples
sed -i -e '1s|^#!perl|#!/usr/bin/perl|' example/*.t

%build
perl Build.PL --installdirs=vendor
./Build

%install
rm -rf %{buildroot}
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
./Build test
prove -Ilib $(echo $(find xt/ -name '*.t'))

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README.md example/
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Vars.3*

%changelog
* Fri Mar 17 2017 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013
  - Worked around a very weird bug with B's handling of multideref aux_list
    values on 5.22 and 5.24. This could cause a warning like "Use of
    uninitialized value $i in array element at lib/Test/Vars.pm line ..." when
    testing certain Perl constructs for unused vars; this appears to be fixed
    in blead's B
- Drop patch for building with Test::More < 0.88 as we always have that now

* Sun Dec 11 2016 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012
  - On Perl 5.22+, variables used in a substitution operator
    ($foo =~ s/foo/bar/) would be ignored (GH#28)

* Mon Oct 17 2016 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011
  - Fixed tests to pass on Windows (GH#26 and GH#27)
- This release by DROLSKY → update source URL

* Fri Jul  1 2016 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Fix for pp_match in Perl 5.22+ (GH#23)
- This release by GFUJI → update source URL
- Update patch for building with old Test::More versions

* Sun May 22 2016 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - On recent Perls (5.22 and 5.24, maybe more) this module could detect an
    unused variable named "$"; this was a bogus false positive, as opposed to
    just a missing variable name in the output (GH#22)
  - Fixed tests to use File::Spec->catfile to generate paths so that tests pass
    on Windows (based on GH#20)
- Switch to Module::Build::Tiny flow
- Update patch for building with old Test::More versions

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 0.008-3
- Don't BR: perl(Moose::Role) when bootstrapping
- BR: perl-generators where available

* Thu Aug 20 2015 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - In some corner cases, Test::Vars would try to look inside the body of a
    stub sub ("sub foo;") and then blow up; this could be triggered by
    declaring a stub sub and then an attribute with a reader of the same name
    in a Moose::Role, for example
- Update patch for building with old Test::More versions

* Wed Aug 19 2015 Paul Howarth <paul@city-fan.org> - 0.007-1
- Update to 0.007
  - Fix tests with threaded Perl 5.22+

* Wed Aug 19 2015 Paul Howarth <paul@city-fan.org> - 0.006-1
- Update to 0.006
  - This module now calls Test::Builder->diag and ->note _after_ calling ->ok;
    this is more in line with how most test modules work
  - Added a new exported sub, test_vars(), which does not output TAP; this is
    useful for integrating this module with things like Code::TidyAll
- This release by DROLSKY → update source URL
- Update patch for building with old Test::More versions

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 0.005-6
- Use %%license where possible

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.005-3
- Specify all dependencies

* Fri May 31 2013 Paul Howarth <paul@city-fan.org> - 0.005-1
- Update to 0.005
  - Use skip_all instead of planning 0 tests (#4)

* Sun May  5 2013 Paul Howarth <paul@city-fan.org> - 0.004-1
- Update to 0.004
  - Re-package with Module::Build
  - Remove an unnecessary use of smart match operator
- Switch to Module::Build flow
- Classify buildreqs by usage
- Drop Test::Spelling requirement, no longer used

* Wed Oct 10 2012 Paul Howarth <paul@city-fan.org> - 0.002-1
- Update to 0.002
  - Fix compatibility with Perl 5.16 (CPAN RT#72133)
- Drop upstreamed patch for 5.16 compatibility
- Update patch for building with old Test::More versions

* Wed Jun 13 2012 Paul Howarth <paul@city-fan.org> - 0.001-5
- Fix compatibility with Perl 5.16 (CPAN RT#72133)
- Don't need to remove empty directories from buildroot
- Drop %%defattr, redundant since rpm 4.4
- Use %%{_fixperms} macro rather than our own chmod incantation
- Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Aug  8 2011 Paul Howarth <paul@city-fan.org> - 0.001-1
- Initial RPM version
